@@ -17,8 +17,6 @@ which has a similar API.
 
 """
 
-from __future__ import division, print_function, absolute_import
-
 # TODO:
 # * properly implement ``_FillValue``.
 # * fix character variables.
@@ -50,7 +48,6 @@ from numpy import frombuffer, dtype, empty, array, asarray
 from numpy import little_endian as LITTLE_ENDIAN
 from functools import reduce
 
-from scipy._lib.six import integer_types, text_type, binary_type
 
 IS_PYPY = ('__pypy__' in sys.modules)
 
@@ -144,7 +141,7 @@ class netcdf_file(object):
     NetCDF files are a self-describing binary data format. The file contains
     metadata that describes the dimensions and variables in the file. More
     details about NetCDF files can be found `here
-    <https://www.unidata.ucar.edu/software/netcdf/docs/user_guide.html>`__. There
+    <https://www.unidata.ucar.edu/software/netcdf/guide_toc.html>`__. There
     are three main sections to a NetCDF data structure:
 
     1. Dimensions
@@ -330,7 +327,7 @@ class netcdf_file(object):
         Adds a dimension to the Dimension section of the NetCDF data structure.
 
         Note that this function merely adds a new dimension that the variables can
-        reference.  The values for the dimension, if desired, should be added as
+        reference. The values for the dimension, if desired, should be added as
         a variable using `createVariable`, referring to this dimension.
 
         Parameters
@@ -383,7 +380,7 @@ class netcdf_file(object):
 
         """
         shape = tuple([self.dimensions[dim] for dim in dimensions])
-        shape_ = tuple([dim or 0 for dim in shape])  # replace None with 0 for numpy
+        shape_ = tuple([dim or 0 for dim in shape])  # replace None with 0 for NumPy
 
         type = dtype(type)
         typecode, size = type.char, type.itemsize
@@ -412,7 +409,7 @@ class netcdf_file(object):
     def _write(self):
         self.fp.seek(0)
         self.fp.write(b'CDF')
-        self.fp.write(array(self.version_byte, '>b').tostring())
+        self.fp.write(array(self.version_byte, '>b').tobytes())
 
         # Write headers and data.
         self._write_numrecs()
@@ -522,7 +519,7 @@ class netcdf_file(object):
 
         # Write data.
         if not var.isrec:
-            self.fp.write(var.data.tostring())
+            self.fp.write(var.data.tobytes())
             count = var.data.size * var.data.itemsize
             self._write_var_padding(var, var._vsize - count)
         else:  # record variable
@@ -544,7 +541,7 @@ class netcdf_file(object):
                 if not rec.shape and (rec.dtype.byteorder == '<' or
                         (rec.dtype.byteorder == '=' and LITTLE_ENDIAN)):
                     rec = rec.byteswap()
-                self.fp.write(rec.tostring())
+                self.fp.write(rec.tobytes())
                 # Padding
                 count = rec.size * rec.itemsize
                 self._write_var_padding(var, var._vsize - count)
@@ -561,13 +558,10 @@ class netcdf_file(object):
         if hasattr(values, 'dtype'):
             nc_type = REVERSE[values.dtype.char, values.dtype.itemsize]
         else:
-            types = [(t, NC_INT) for t in integer_types]
-            types += [
-                    (float, NC_FLOAT),
-                    (str, NC_CHAR)
-                    ]
-            # bytes index into scalars in py3k.  Check for "string" types
-            if isinstance(values, text_type) or isinstance(values, binary_type):
+            types = [(int, NC_INT), (float, NC_FLOAT), (str, NC_CHAR)]
+
+            # bytes index into scalars in py3k. Check for "string" types
+            if isinstance(values, (str, bytes)):
                 sample = values
             else:
                 try:
@@ -581,7 +575,7 @@ class netcdf_file(object):
 
         typecode, size = TYPEMAP[nc_type]
         dtype_ = '>%s' % typecode
-        # asarray() dies with bytes and '>c' in py3k.  Change to 'S'
+        # asarray() dies with bytes and '>c' in py3k. Change to 'S'
         dtype_ = 'S' if dtype_ == '>c' else dtype_
 
         values = asarray(values, dtype=dtype_)
@@ -597,7 +591,7 @@ class netcdf_file(object):
         if not values.shape and (values.dtype.byteorder == '<' or
                 (values.dtype.byteorder == '=' and LITTLE_ENDIAN)):
             values = values.byteswap()
-        self.fp.write(values.tostring())
+        self.fp.write(values.tobytes())
         count = values.size * values.itemsize
         self.fp.write(b'\x00' * (-count % 4))  # pad
 
@@ -658,7 +652,7 @@ class netcdf_file(object):
         for var in range(count):
             (name, dimensions, shape, attributes,
              typecode, size, dtype_, begin_, vsize) = self._read_var()
-            # https://www.unidata.ucar.edu/software/netcdf/docs/user_guide.html
+            # https://www.unidata.ucar.edu/software/netcdf/guide_toc.html
             # Note that vsize is the product of the dimension lengths
             # (omitting the record dimension) and the number of bytes
             # per value (determined from the type), increased to the
@@ -767,7 +761,7 @@ class netcdf_file(object):
         values = self.fp.read(int(count))
         self.fp.read(-count % 4)  # read padding
 
-        if typecode is not 'c':
+        if typecode != 'c':
             values = frombuffer(values, dtype='>%s' % typecode).copy()
             if values.shape == (1,):
                 values = values[0]
@@ -782,7 +776,7 @@ class netcdf_file(object):
             self._pack_int64(begin)
 
     def _pack_int(self, value):
-        self.fp.write(array(value, '>i').tostring())
+        self.fp.write(array(value, '>i').tobytes())
     _pack_int32 = _pack_int
 
     def _unpack_int(self):
@@ -790,7 +784,7 @@ class netcdf_file(object):
     _unpack_int32 = _unpack_int
 
     def _pack_int64(self, value):
-        self.fp.write(array(value, '>q').tostring())
+        self.fp.write(array(value, '>q').tobytes())
 
     def _unpack_int64(self):
         return frombuffer(self.fp.read(8), '>q')[0]
@@ -836,13 +830,13 @@ class netcdf_variable(object):
     size : int
         Desired element size for the data array.
     shape : sequence of ints
-        The shape of the array.  This should match the lengths of the
+        The shape of the array. This should match the lengths of the
         variable's dimensions.
     dimensions : sequence of strings
-        The names of the dimensions used by the variable.  Must be in the
+        The names of the dimensions used by the variable. Must be in the
         same order of the dimension lengths given by `shape`.
     attributes : dict, optional
-        Attribute values (any type) keyed by string names.  These attributes
+        Attribute values (any type) keyed by string names. These attributes
         become attributes for the netcdf_variable object.
     maskandscale : bool, optional
         Whether to automatically scale and/or mask data based on attributes.
@@ -940,7 +934,7 @@ class netcdf_variable(object):
             # memory-mapped array causes a seg. fault.
             # See NumPy ticket #1622, and SciPy ticket #1202.
             # This check for `writeable` can be removed when the oldest version
-            # of numpy still supported by scipy contains the fix for #1622.
+            # of NumPy still supported by scipy contains the fix for #1622.
             raise RuntimeError("variable is not writeable")
 
         self.data.itemset(value)
@@ -952,7 +946,7 @@ class netcdf_variable(object):
         Returns
         -------
         typecode : char
-            The character typecode of the variable (eg, 'i' for int).
+            The character typecode of the variable (e.g., 'i' for int).
 
         """
         return self._typecode
@@ -964,7 +958,7 @@ class netcdf_variable(object):
         Returns
         -------
         itemsize : int
-            The element size of the variable (eg, 8 for float64).
+            The element size of the variable (e.g., 8 for float64).
 
         """
         return self._size
@@ -1036,7 +1030,7 @@ class netcdf_variable(object):
         """
         if '_FillValue' in self._attributes:
             fill_value = np.array(self._attributes['_FillValue'],
-                                  dtype=self.data.dtype).tostring()
+                                  dtype=self.data.dtype).tobytes()
             if len(fill_value) == self.itemsize():
                 return fill_value
             else:
@@ -1095,4 +1089,3 @@ class netcdf_variable(object):
 
 NetCDFFile = netcdf_file
 NetCDFVariable = netcdf_variable
-
